# Generated by Django 2.1.14 on 2019-11-22 15:16

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):
    atomic = False
    dependencies = [
        ('djautotask', '0023_auto_20191119_0923'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='TicketStatus',
            new_name='Status',
        ),
        migrations.AlterModelOptions(
            name='status',
            options={'verbose_name_plural': 'Statuses'},
        ),
        migrations.CreateModel(
            name='Task',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('title', models.CharField(blank=True, max_length=255, null=True)),
                ('number', models.CharField(blank=True, max_length=50, null=True)),
                ('description', models.CharField(blank=True, max_length=8000, null=True)),
                ('completed_date', models.DateTimeField(blank=True, null=True)),
                ('create_date', models.DateTimeField(blank=True, null=True)),
                ('start_date', models.DateTimeField(blank=True, null=True)),
                ('end_date', models.DateTimeField(blank=True, null=True)),
                ('estimated_hours', models.PositiveIntegerField(default=0)),
                ('remaining_hours', models.PositiveIntegerField(default=0)),
                ('last_activity_date', models.DateTimeField(blank=True, null=True)),
                ('assigned_resource', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Resource')),
                ('priority_label', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.TicketPriority')),
                ('project', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Project')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TaskSecondaryResource',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('resource', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Resource')),
                ('task', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Task')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='task',
            name='status',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.Status'),
        ),
    ]



# Generated by Django 3.1.7 on 2022-01-04 16:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0101_auto_20220104_1349'),
    ]

    operations = [
        migrations.RenameField(
            model_name='task',
            old_name='task_category',
            new_name='category',
        ),
    ]



# Generated by Django 2.1.14 on 2020-02-06 09:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0044_merge_20200205_1651'),
    ]

    operations = [
        migrations.CreateModel(
            name='ResourceRoleDepartment',
            fields=[
                ('id', models.BigAutoField(primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True)),
                ('default', models.BooleanField(default=False)),
                ('department_lead', models.BooleanField(default=False)),
                ('department', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Department')),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Resource')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Role')),
            ],
        ),
        migrations.CreateModel(
            name='ResourceServiceDeskRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('active', models.BooleanField(default=True)),
                ('default', models.BooleanField(default=False)),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Resource')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Role')),
            ],
        ),
    ]



from collections import OrderedDict

from django.core.management.base import BaseCommand, CommandError
from django.utils.translation import gettext_lazy as _
from djautotask import sync
from djautotask import api

OPTION_NAME = 'autotask_object'
ERROR_MESSAGE_TEMPLATE = 'Failed to sync {}. Autotask API returned an ' \
                         'error(s): {}.'


class Command(BaseCommand):
    help = str(_('Synchronize the specified object with the Autotask API'))

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        # This can be replaced with a single instantiation of an OrderedDict
        # using kwargs in Python 3.6. But we need Python 3.5 compatibility for
        # now.
        # See https://www.python.org/dev/peps/pep-0468/.
        synchronizers = (
            ('ticket_udf', sync.TicketUDFSynchronizer, _('Ticket Udf')),
            ('task_udf', sync.TaskUDFSynchronizer, _('Task Udf')),
            ('project_udf', sync.ProjectUDFSynchronizer, _('Project Udf')),
            ('status', sync.StatusSynchronizer, _('Status')),
            (
                'license_type',
                sync.LicenseTypeSynchronizer,
                _('License Type')
            ),
            ('resource', sync.ResourceSynchronizer, _('Resource')),
            ('ticket_secondary_resource',
             sync.TicketSecondaryResourceSynchronizer,
             _('Ticket Secondary Resource')),
            ('priority', sync.PrioritySynchronizer, _('Priority')),
            ('queue', sync.QueueSynchronizer, _('Queue')),
            (
                'account_type',
                sync.AccountTypeSynchronizer,
                _('Account Type')
            ),
            ('account', sync.AccountSynchronizer, _('Account')),
            (
                'account_physical_location',
                sync.AccountPhysicalLocationSynchronizer,
                _('Account Physical Location')
            ),
            ('contract', sync.ContractSynchronizer, _('Contract')),
            ('project_status',
             sync.ProjectStatusSynchronizer, _('Project Status')),
            ('project_type',
             sync.ProjectTypeSynchronizer, _('Project Type')),
            ('project', sync.ProjectSynchronizer, _('Project')),
            ('phase', sync.PhaseSynchronizer, _('Phase')),
            ('display_color', sync.DisplayColorSynchronizer,
             _('Display Color')),
            ('ticket_category', sync.TicketCategorySynchronizer,
             _('Ticket Category')),
            ('source', sync.SourceSynchronizer, _('Source')),
            ('issue_type', sync.IssueTypeSynchronizer, _('Issue Type')),
            ('ticket_type', sync.TicketTypeSynchronizer, _('Ticket Type')),
            ('sub_issue_type', sync.SubIssueTypeSynchronizer,
             _('Sub Issue Type')),
            ('ticket', sync.TicketSynchronizer, _('Ticket')),
            ('note_type', sync.NoteTypeSynchronizer, _('Note Type')),
            ('ticket_note', sync.TicketNoteSynchronizer, _('Ticket Note')),
            ('use_type', sync.UseTypeSynchronizer, _('Use Type')),
            ('billing_code_type',
             sync.BillingCodeTypeSynchronizer, _('Billing Code Type')),
            ('billing_code', sync.BillingCodeSynchronizer,
             _('Billing Code')),
            ('role', sync.RoleSynchronizer, _('Role')),
            ('department', sync.DepartmentSynchronizer, _('Department')),
            ('time_entry', sync.TimeEntrySynchronizer, _('Time Entry')),
            ('task_category', sync.TaskCategorySynchronizer,
             _('Task Category')),
            ('task', sync.TaskSynchronizer, _('Task')),
            ('task_note', sync.TaskNoteSynchronizer, _('Task Note')),
            ('task_type_link', sync.TaskTypeLinkSynchronizer,
             _('Task Type Link')),
            ('task_secondary_resource',
             sync.TaskSecondaryResourceSynchronizer,
             _('Task Secondary Resource')),
            (
                'resource_role_department',
                sync.ResourceRoleDepartmentSynchronizer,
                _('Resource Role Department')
            ),
            (
                'resource_service_desk_role',
                sync.ResourceServiceDeskRoleSynchronizer,
                _('Resource Service Desk Role')
            ),
            (
                'service_call_status',
                sync.ServiceCallStatusSynchronizer,
                _('Service Call Status')
            ),
            (
                'service_call',
                sync.ServiceCallSynchronizer,
                _('Service Call')
            ),
            (
                'service_call_ticket',
                sync.ServiceCallTicketSynchronizer,
                _('Service Call Ticket')
            ),
            (
                'service_call_task',
                sync.ServiceCallTaskSynchronizer,
                _('Service Call Task')
            ),
            (
                'service_call_ticket_resource',
                sync.ServiceCallTicketResourceSynchronizer,
                _('Service Call Ticket Resource')
            ),
            (
                'service_call_task_resource',
                sync.ServiceCallTaskResourceSynchronizer,
                _('Service Call Task Resource')
            ),
            ('task_predecessor', sync.TaskPredecessorSynchronizer,
             _('Task Predecessor')),
            ('contact', sync.ContactSynchronizer, _('Contact')),
        )
        self.synchronizer_map = OrderedDict()
        for name, synchronizer, obj_name in synchronizers:
            self.synchronizer_map[name] = (synchronizer, obj_name)

    def add_arguments(self, parser):
        parser.add_argument(OPTION_NAME, nargs='?', type=str)
        parser.add_argument('--full',
                            action='store_true',
                            dest='full',
                            default=False)

    def sync_by_class(self, sync_class, obj_name, full_option=False):
        synchronizer = sync_class(full=full_option)

        created_count, updated_count, skipped_count, deleted_count = \
            synchronizer.sync()

        msg = _('{} Sync Summary - Created: {}, Updated: {}, Skipped: {}')
        fmt_msg = msg.format(obj_name, created_count, updated_count,
                             skipped_count)

        if full_option:
            msg = _('{} Sync Summary - Created: {}, Updated: {}, Skipped: {}, '
                    'Deleted: {}')
            fmt_msg = msg.format(obj_name, created_count, updated_count,
                                 skipped_count, deleted_count)

        self.stdout.write(fmt_msg)

    def handle(self, *args, **options):
        sync_classes = []
        autotask_object_arg = options[OPTION_NAME]
        full_option = options.get('full', False)

        if autotask_object_arg:
            object_arg = autotask_object_arg
            sync_tuple = self.synchronizer_map.get(object_arg)

            if sync_tuple:
                sync_classes.append(sync_tuple)
            else:
                msg = _('Invalid AT object {}, '
                        'choose one of the following: \n{}')
                options_txt = ', '.join(self.synchronizer_map.keys())
                msg = msg.format(sync_tuple, options_txt)
                raise CommandError(msg)
        else:
            sync_classes = self.synchronizer_map.values()

        failed_classes = 0
        error_messages = ''

        for sync_class, obj_name in sync_classes:
            error_msg = None
            try:
                self.sync_by_class(sync_class, obj_name,
                                   full_option=full_option)
            except api.AutotaskSecurityPermissionsException as e:
                self.stderr.write(ERROR_MESSAGE_TEMPLATE.format(obj_name, e))
            except api.AutotaskAPIError as e:
                error_msg = ERROR_MESSAGE_TEMPLATE.format(obj_name, e)

            finally:
                if error_msg:
                    self.stderr.write(error_msg)
                    error_messages += '{}\n'.format(error_msg)
                    failed_classes += 1

        if failed_classes > 0:
            msg = '{} class{} failed to sync.\n'.format(
                failed_classes,
                '' if failed_classes == 1 else 'es',
            )
            msg += 'Errors:\n'
            msg += error_messages
            raise CommandError(msg)



# Generated by Django 3.1.2 on 2021-01-08 13:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0086_auto_20201222_1402'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='phone',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='alternate_phone',
            field=models.CharField(blank=True, max_length=32, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='mobile_phone',
            field=models.CharField(blank=True, max_length=25, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='email_address2',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='contact',
            name='email_address3',
            field=models.CharField(blank=True, max_length=50, null=True),
        ),
    ]



# Generated by Django 2.1.11 on 2019-10-30 09:16

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0019_auto_20191030_0905'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='resource',
            managers=[
            ],
        ),
    ]



# Generated by Django 2.1.14 on 2020-09-18 14:29

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0074_auto_20200827_1818'),
    ]

    operations = [
        migrations.CreateModel(
            name='TaskPredecessor',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('lag_days', models.IntegerField(blank=True, null=True)),
                ('predecessor_task', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='predecessor_task', to='djautotask.Task')),
                ('successor_task', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='successor_task', to='djautotask.Task')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
    ]



# Generated by Django 3.1.7 on 2022-01-04 13:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0100_auto_20211228_1443'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='taskcategory',
            options={'verbose_name_plural': 'Task categories'},
        ),
    ]



# Generated by Django 2.1.14 on 2020-06-02 14:19

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0068_merge_20200521_1615'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicecalltask',
            name='service_call',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.ServiceCall'),
        ),
        migrations.AlterField(
            model_name='servicecallticket',
            name='service_call',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.ServiceCall'),
        ),
    ]



# Generated by Django 3.1.2 on 2020-12-22 14:02

from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0085_auto_20201022_1822'),
    ]

    operations = [
        migrations.CreateModel(
            name='Contact',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('first_name', models.CharField(blank=True, max_length=20, null=True)),
                ('last_name', models.CharField(blank=True, max_length=20, null=True)),
                ('email_address', models.CharField(blank=True, max_length=50, null=True)),
                ('account', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.account')),
            ],
            options={
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ContactTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_contact',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.contact',),
        ),
        migrations.AddField(
            model_name='project',
            name='contact',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.contact'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='contact',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djautotask.contact'),
        ),
    ]



# Generated by Django 4.0.7 on 2022-11-01 15:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0110_account_phone'),
    ]

    operations = [
        migrations.AlterField(
            model_name='phase',
            name='estimated_hours',
            field=models.DecimalField(decimal_places=2, default=0.0, max_digits=9),
        ),
    ]



# Generated by Django 2.1.11 on 2020-04-14 15:22

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0059_auto_20200414_1242'),
    ]

    operations = [
        migrations.AlterField(
            model_name='servicecall',
            name='canceled_by_resource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='cancelled_service_calls', to='djautotask.Resource'),
        ),
        migrations.AlterField(
            model_name='servicecall',
            name='creator_resource',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='created_service_calls', to='djautotask.Resource'),
        ),
    ]



from django.contrib import admin
import datetime

from . import models


class TicketSecondaryResourceInline(admin.StackedInline):
    model = models.TicketSecondaryResource


@admin.register(models.Ticket)
class TicketAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'ticket_number', 'status')
    list_filter = ('status',)
    search_fields = ('id', 'title', 'ticket_number', 'status__label')

    inlines = [
        TicketSecondaryResourceInline
    ]

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('status')


@admin.register(models.SyncJob)
class SyncJobAdmin(admin.ModelAdmin):
    actions = None
    change_form_template = 'change_form.html'
    list_display = (
        'id', 'start_time', 'end_time', 'duration_or_zero', 'entity_name',
        'success', 'added', 'updated', 'skipped', 'deleted', 'sync_type',
    )
    list_filter = ('sync_type', 'success', 'entity_name', )

    def has_add_permission(self, request):
        return False

    def has_change_permission(self, request, obj=None):
        return False

    def has_delete_permission(self, request, obj=None):
        return False

    def duration_or_zero(self, obj):
        """
        Return the duration, or just the string 0 (otherwise we get 0:00:00)
        """
        duration = obj.duration()
        if duration:
            # Get rid of the microseconds part
            duration_seconds = duration - datetime.timedelta(
                microseconds=duration.microseconds
            )
            return duration_seconds if duration_seconds else '0'
    duration_or_zero.short_description = 'Duration'


@admin.register(models.Status)
class StatusAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active', 'is_system')


@admin.register(models.Priority)
class PriorityAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.Queue)
class QueueAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.ProjectStatus)
class ProjectStatusAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')


@admin.register(models.ProjectType)
class ProjectTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.TicketCategory)
class TicketCategoryAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'active')


@admin.register(models.TaskCategory)
class TaskCategoryAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')


@admin.register(models.Source)
class SourceAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.IssueType)
class IssueTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.SubIssueType)
class SubIssueType(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.TicketType)
class TicketTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.AccountType)
class AccountTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.Contact)
class ContactAdmin(admin.ModelAdmin):
    list_display = ('id', 'full_name')
    search_fields = ('id', 'first_name', 'last_name')
    list_filter = ('account__name', )

    def full_name(self, obj):
        return str(obj)

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('account')


@admin.register(models.DisplayColor)
class DisplayColorAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')


@admin.register(models.LicenseType)
class LicenseTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.ServiceCallStatus)
class ServiceCallStatusAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.Resource)
class ResourceAdmin(admin.ModelAdmin):
    list_display = (
        'user_name', 'full_name', 'email', 'active', 'license_type'
    )
    list_filter = ('active', 'license_type')
    search_fields = ('user_name', 'first_name', 'last_name', 'email')

    def full_name(self, obj):
        return str(obj)


@admin.register(models.TicketSecondaryResource)
class TicketSecondaryResourceAdmin(admin.ModelAdmin):
    list_display = ('id', 'resource', 'ticket')


@admin.register(models.Account)
class AccountAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'type', 'number', 'active', 'parent_account')
    search_fields = ('id', 'name', 'number', 'parent_account__name')
    list_filter = ('active', 'type')


@admin.register(models.AccountPhysicalLocation)
class AccountPhysicalLocationAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'account', 'active')
    search_fields = ('id', 'name', 'account')
    list_filter = ('active',)


@admin.register(models.Project)
class ProjectAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'number', 'type', 'status')
    list_filter = ('type', 'status')
    search_fields = ('id', 'name', 'number')

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('type', 'status')


@admin.register(models.Task)
class TaskAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'number', 'status', 'phase')
    list_filter = ('status',)
    search_fields = ('id', 'title', 'number', 'status__label', 'phase__title')

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('phase', 'status')


@admin.register(models.TaskSecondaryResource)
class TaskSecondaryResourceAdmin(admin.ModelAdmin):
    list_display = ('id', 'resource', 'task')


@admin.register(models.Phase)
class PhaseTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'parent_phase')
    search_fields = ('id', 'title')


@admin.register(models.NoteType)
class NoteTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label')


@admin.register(models.Role)
class RoleAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'description', 'hourly_rate')
    search_fields = ('id', 'name', 'description')


@admin.register(models.Department)
class DepartmentAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'description')
    search_fields = ('id', 'name', 'description')


@admin.register(models.TicketNote)
class TicketNoteAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'description', 'ticket')
    search_fields = ('id', 'title')


@admin.register(models.TaskNote)
class TaskNoteAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'description', 'task')
    search_fields = ('id', 'title')


@admin.register(models.TimeEntry)
class TimeEntryAdmin(admin.ModelAdmin):
    list_display = ('id', 'resource', 'ticket', 'task',
                    'date_worked', 'start_date_time', 'end_date_time')
    list_filter = ('resource', )
    search_fields = [
        'id', 'resource__user_name', 'ticket__title', 'task__title']

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('resource', 'ticket', 'task')


@admin.register(models.TaskTypeLink)
class TaskTypeLinkAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')
    search_fields = ('id', 'label')


@admin.register(models.UseType)
class UseTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')
    search_fields = ('id', 'label')


@admin.register(models.BillingCodeType)
class BillingCodeTypeAdmin(admin.ModelAdmin):
    list_display = ('id', 'label', 'is_active')
    search_fields = ('id', 'label')


@admin.register(models.BillingCode)
class BillingCodeAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'active', 'use_type')
    list_filter = ('use_type', )
    search_fields = ('id', 'name')

    def get_queryset(self, request):
        qs = super().get_queryset(request)
        return qs.select_related('use_type')


@admin.register(models.ResourceRoleDepartment)
class ResourceRoleDepartmentAdmin(admin.ModelAdmin):
    list_display = \
        ('id', 'resource', 'role', 'department', 'active', 'default')
    search_fields = (
        'id',
        'resource__first_name',
        'role__name',
        'department__name'
    )


@admin.register(models.ResourceServiceDeskRole)
class ResourceServiceDeskRoleAdmin(admin.ModelAdmin):
    list_display = ('id', 'resource', 'role', 'active', 'default')
    search_fields = ('id', 'resource__first_name')


@admin.register(models.Contract)
class ContractAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'number', 'account', 'status_name')
    search_fields = ('id', 'name', 'number')
    list_filter = ('status',)

    def status_name(self, obj):
        return obj.STATUS_CHOICES[int(obj.status)][1]


@admin.register(models.ServiceCall)
class ServiceCallAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'description',
        'creator_resource',
        'status',
        'duration',
        'start_date_time',
        'end_date_time',
    )
    search_fields = ('id', 'description')
    list_filter = ('status', 'creator_resource')


@admin.register(models.ServiceCallTicket)
class ServiceCallTicketAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'service_call',
        'ticket',
    )
    search_fields = ('id', 'service_call__description')


@admin.register(models.ServiceCallTask)
class ServiceCallTaskAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'service_call',
        'task',
    )
    search_fields = ('id', 'service_call__description')


@admin.register(models.ServiceCallTicketResource)
class ServiceCallTicketResourceAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'service_call_ticket',
        'resource',
    )
    search_fields = ('id', 'resource__first_name', 'resource__last_name')


@admin.register(models.ServiceCallTaskResource)
class ServiceCallTaskResourceAdmin(admin.ModelAdmin):
    list_display = (
        'id',
        'service_call_task',
        'resource',
    )
    search_fields = ('id', 'resource__first_name', 'resource__last_name')


@admin.register(models.TaskPredecessor)
class TaskPredecessorAdmin(admin.ModelAdmin):
    list_display = (
        'id', 'predecessor_task', 'successor_task', 'lag_days'
    )
    search_fields = ('id', 'predecessor_task__title', 'successor_task__title')


@admin.register(models.TicketUDF)
class TicketUDFAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'type', 'is_picklist')
    search_fields = ['name', 'type']


@admin.register(models.TaskUDF)
class TaskUDFAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'type', 'is_picklist')
    search_fields = ['name', 'type']


@admin.register(models.ProjectUDF)
class ProjectUDFAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'type', 'is_picklist')
    search_fields = ['name', 'type']



# Generated by Django 2.1.11 on 2020-05-08 11:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0062_task_department'),
    ]

    operations = [
        migrations.CreateModel(
            name='AccountPhysicalLocation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('active', models.BooleanField(default=True)),
                ('account', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='djautotask.Account')),
            ],
            options={
                'ordering': ('name',),
            },
        ),
    ]
